@@ -1,7 +1,7 @@
 
 # cfg.py - module for accessing configuration information
 #
-# Copyright (C) 2010-2017 Arthur de Jong
+# Copyright (C) 2010-2019 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -133,23 +133,23 @@ _tls_reqcert_options = {'never': ldap.OPT_X_TLS_NEVER,
 
 def _get_maps():
     # separate function as not to pollute the namespace and avoid import loops
-    import alias, ether, group, host, netgroup, network, passwd
-    import protocol, rpc, service, shadow
+    import alias, ether, group, host, netgroup, network, passwd  # noqa: E401
+    import protocol, rpc, service, shadow  # noqa: E401
     import sys
     return dict(
-            alias=alias, aliases=alias,
-            ether=ether, ethers=ether,
-            group=group,
-            host=host, hosts=host,
-            netgroup=netgroup,
-            network=network, networks=network,
-            passwd=passwd,
-            protocol=protocol, protocols=protocol,
-            rpc=rpc,
-            service=service, services=service,
-            shadow=shadow,
-            none=sys.modules[__name__]
-        )
+        alias=alias, aliases=alias,
+        ether=ether, ethers=ether,
+        group=group,
+        host=host, hosts=host,
+        netgroup=netgroup,
+        network=network, networks=network,
+        passwd=passwd,
+        protocol=protocol, protocols=protocol,
+        rpc=rpc,
+        service=service, services=service,
+        shadow=shadow,
+        none=sys.modules[__name__],
+    )
 
 
 class ParseError(Exception):
@@ -163,49 +163,60 @@ class ParseError(Exception):
     __str__ = __repr__
 
 
-def read(filename):
+def read(filename):  # noqa: C901 (many simple branches)
     maps = _get_maps()
     lineno = 0
     for line in open(filename, 'r'):
         lineno += 1
         line = line.strip()
         # skip comments and blank lines
-        if re.match('(#.*)?$', line, re.IGNORECASE):
+        if re.match(r'(#.*)?$', line, re.IGNORECASE):
             continue
         # parse options with a single integer argument
-        m = re.match('(?P<keyword>threads|ldap_version|bind_timelimit|timelimit|idle_timelimit|reconnect_sleeptime|reconnect_retrytime|pagesize|nss_min_uid|nss_uid_offset|nss_gid_offset)\s+(?P<value>\d+)',
-                     line, re.IGNORECASE)
+        m = re.match(
+            r'(?P<keyword>threads|ldap_version|bind_timelimit|timelimit|'
+            r'idle_timelimit|reconnect_sleeptime|reconnect_retrytime|pagesize|'
+            r'nss_min_uid|nss_uid_offset|nss_gid_offset)\s+(?P<value>\d+)',
+            line, re.IGNORECASE)
         if m:
             globals()[m.group('keyword').lower()] = int(m.group('value'))
             continue
         # parse options with a single boolean argument
-        m = re.match('(?P<keyword>referrals|nss_nested_groups|nss_getgrent_skipmembers|nss_disable_enumeration)\s+(?P<value>%s)' %
-                         '|'.join(_boolean_options.keys()),
-                     line, re.IGNORECASE)
+        m = re.match(
+            r'(?P<keyword>referrals|nss_nested_groups|nss_getgrent_skipmembers|'
+            r'nss_disable_enumeration)\s+(?P<value>%s)' % (
+                '|'.join(_boolean_options.keys())),
+            line, re.IGNORECASE)
         if m:
             globals()[m.group('keyword').lower()] = _boolean_options[m.group('value').lower()]
             continue
         # parse options with a single no-space value
-        m = re.match('(?P<keyword>uid|gid|bindpw|rootpwmodpw|sasl_mech)\s+(?P<value>\S+)',
-                     line, re.IGNORECASE)
+        m = re.match(
+            r'(?P<keyword>uid|gid|bindpw|rootpwmodpw|sasl_mech)\s+(?P<value>\S+)',
+            line, re.IGNORECASE)
         if m:
             globals()[m.group('keyword').lower()] = m.group('value')
             continue
         # parse options with a single value that can contain spaces
-        m = re.match('(?P<keyword>binddn|rootpwmoddn|sasl_realm|sasl_authcid|sasl_authzid|sasl_secprops|krb5_ccname|tls_cacertdir|tls_cacertfile|tls_randfile|tls_ciphers|tls_cert|tls_key|pam_password_prohibit_message)\s+(?P<value>\S.*)',
-                     line, re.IGNORECASE)
+        m = re.match(
+            r'(?P<keyword>binddn|rootpwmoddn|sasl_realm|sasl_authcid|'
+            r'sasl_authzid|sasl_secprops|krb5_ccname|tls_cacertdir|'
+            r'tls_cacertfile|tls_randfile|tls_ciphers|tls_cert|tls_key|'
+            r'pam_password_prohibit_message)\s+(?P<value>\S.*)',
+            line, re.IGNORECASE)
         if m:
             globals()[m.group('keyword').lower()] = m.group('value')
             continue
         # log <SCHEME> [<LEVEL>]
-        m = re.match('log\s+(?P<scheme>syslog|/\S*)(\s+(?P<level>%s))?' %
-                         '|'.join(_log_levels.keys()),
-                     line, re.IGNORECASE)
+        m = re.match(
+            r'log\s+(?P<scheme>syslog|/\S*)(\s+(?P<level>%s))?' % (
+                '|'.join(_log_levels.keys())),
+            line, re.IGNORECASE)
         if m:
             logs.append((m.group('scheme'), _log_levels[str(m.group('level')).lower()]))
             continue
         # uri <URI>
-        m = re.match('uri\s+(?P<uri>\S+)', line, re.IGNORECASE)
+        m = re.match(r'uri\s+(?P<uri>\S+)', line, re.IGNORECASE)
         if m:
             # FIXME: support multiple URI values
             # FIXME: support special DNS and DNS:domain values
@@ -213,9 +224,10 @@ def read(filename):
             uri = m.group('uri')
             continue
         # base <MAP>? <BASEDN>
-        m = re.match('base\s+((?P<map>%s)\s+)?(?P<value>\S.*)' %
-                         '|'.join(maps.keys()),
-                     line, re.IGNORECASE)
+        m = re.match(
+            r'base\s+((?P<map>%s)\s+)?(?P<value>\S.*)' % (
+                '|'.join(maps.keys())),
+            line, re.IGNORECASE)
         if m:
             mod = maps[str(m.group('map')).lower()]
             if not hasattr(mod, 'bases'):
@@ -223,26 +235,29 @@ def read(filename):
             mod.bases.append(m.group('value'))
             continue
         # filter <MAP> <SEARCHFILTER>
-        m = re.match('filter\s+(?P<map>%s)\s+(?P<value>\S.*)' %
-                         '|'.join(maps.keys()),
-                     line, re.IGNORECASE)
+        m = re.match(
+            r'filter\s+(?P<map>%s)\s+(?P<value>\S.*)' % (
+                '|'.join(maps.keys())),
+            line, re.IGNORECASE)
         if m:
             mod = maps[m.group('map').lower()]
             mod.filter = m.group('value')
             continue
         # scope <MAP>? <SCOPE>
-        m = re.match('scope\s+((?P<map>%s)\s+)?(?P<value>%s)' % (
-                         '|'.join(maps.keys()),
-                         '|'.join(_scope_options.keys())),
-                     line, re.IGNORECASE)
+        m = re.match(
+            r'scope\s+((?P<map>%s)\s+)?(?P<value>%s)' % (
+                '|'.join(maps.keys()),
+                '|'.join(_scope_options.keys())),
+            line, re.IGNORECASE)
         if m:
             mod = maps[str(m.group('map')).lower()]
             mod.scope = _scope_options[m.group('value').lower()]
             continue
         # map <MAP> <ATTRIBUTE> <ATTMAPPING>
-        m = re.match('map\s+(?P<map>%s)\s+(?P<attribute>\S+)\s+(?P<value>\S.*)' %
-                         '|'.join(maps.keys()),
-                     line, re.IGNORECASE)
+        m = re.match(
+            r'map\s+(?P<map>%s)\s+(?P<attribute>\S+)\s+(?P<value>\S.*)' % (
+                '|'.join(maps.keys())),
+            line, re.IGNORECASE)
         if m:
             mod = maps[m.group('map').lower()]
             attribute = m.group('attribute')
@@ -252,15 +267,17 @@ def read(filename):
             # TODO: filter out attributes that cannot be an expression
             continue
         # deref <DEREF>
-        m = re.match('deref\s+(?P<value>%s)' % '|'.join(_deref_options.keys()),
-                     line, re.IGNORECASE)
+        m = re.match(
+            r'deref\s+(?P<value>%s)' % '|'.join(_deref_options.keys()),
+            line, re.IGNORECASE)
         if m:
             global deref
             deref = _deref_options[m.group('value').lower()]
             continue
         # nss_initgroups_ignoreusers <USER,USER>|<ALLLOCAL>
-        m = re.match('nss_initgroups_ignoreusers\s+(?P<value>\S.*)',
-                     line, re.IGNORECASE)
+        m = re.match(
+            r'nss_initgroups_ignoreusers\s+(?P<value>\S.*)',
+            line, re.IGNORECASE)
         if m:
             users = m.group('value')
             if users.lower() == 'alllocal':
@@ -274,7 +291,7 @@ def read(filename):
             nss_initgroups_ignoreusers.update(users)
             continue
         # pam_authz_search <FILTER>
-        m = re.match('pam_authz_search\s+(?P<value>\S.*)', line, re.IGNORECASE)
+        m = re.match(r'pam_authz_search\s+(?P<value>\S.*)', line, re.IGNORECASE)
         if m:
             from expr import Expression
             pam_authz_searches.append(Expression(m.group('value')))
@@ -283,16 +300,18 @@ def read(filename):
             # uid variables
             continue
         # ssl <on|off|start_tls>
-        m = re.match('ssl\s+(?P<value>%s)' % '|'.join(_ssl_options.keys()),
-                     line, re.IGNORECASE)
+        m = re.match(
+            r'ssl\s+(?P<value>%s)' % '|'.join(_ssl_options.keys()),
+            line, re.IGNORECASE)
         if m:
             global ssl
             ssl = _ssl_options[m.group('value').lower()]
             continue
         # sasl_canonicalize yes|no
-        m = re.match('(ldap_?)?sasl_(?P<no>no)?canon(icali[sz]e)?\s+(?P<value>%s)' %
-                         '|'.join(_boolean_options.keys()),
-                     line, re.IGNORECASE)
+        m = re.match(
+            r'(ldap_?)?sasl_(?P<no>no)?canon(icali[sz]e)?\s+(?P<value>%s)' % (
+                '|'.join(_boolean_options.keys())),
+            line, re.IGNORECASE)
         if m:
             global sasl_canonicalize
             sasl_canonicalize = _boolean_options[m.group('value').lower()]
@@ -300,28 +319,31 @@ def read(filename):
                 sasl_canonicalize = not sasl_canonicalize
             continue
         # tls_reqcert <demand|hard|yes...>
-        m = re.match('tls_reqcert\s+(?P<value>%s)' %
-                         '|'.join(_tls_reqcert_options.keys()),
-                     line, re.IGNORECASE)
+        m = re.match(
+            r'tls_reqcert\s+(?P<value>%s)' % (
+                '|'.join(_tls_reqcert_options.keys())),
+            line, re.IGNORECASE)
         if m:
             global tls_reqcert
             tls_reqcert = _tls_reqcert_options[m.group('value').lower()]
             continue
         # validnames /REGEX/i?
-        m = re.match('validnames\s+/(?P<value>.*)/(?P<flags>[i]?)$',
-                     line, re.IGNORECASE)
+        m = re.match(
+            r'validnames\s+/(?P<value>.*)/(?P<flags>[i]?)$',
+            line, re.IGNORECASE)
         if m:
             global validnames
             flags = 0 | re.IGNORECASE if m.group('flags') == 'i' else 0
             validnames = re.compile(m.group('value'), flags=flags)
             continue
         # reconnect_invalidate <MAP>,<MAP>,...
-        m = re.match('reconnect_invalidate\s+(?P<value>\S.*)',
-                     line, re.IGNORECASE)
+        m = re.match(
+            r'reconnect_invalidate\s+(?P<value>\S.*)',
+            line, re.IGNORECASE)
         if m:
             dbs = re.split('[ ,]+', m.group('value').lower())
             for db in dbs:
-                if db not in maps.keys() + ['nfsidmap']:
+                if db not in list(maps.keys()) + ['nfsidmap']:
                     raise ParseError(filename, lineno, 'map %s unknown' % db)
             reconnect_invalidate.update(dbs)
             continue
